@@ -13,20 +13,15 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
-from __future__ import print_function
 import collections
-
 import os
-import pkg_resources
-import sys
+from urllib import parse
 import uuid
 
 import prettytable
-import six
-from six.moves.urllib import parse
+import stevedore
 
 from cinderclient import exceptions
-from oslo_utils import encodeutils
 
 
 def arg(*args, **kwargs):
@@ -112,10 +107,7 @@ def isunauthenticated(f):
 
 
 def _print(pt, order):
-    if sys.version_info >= (3, 0):
-        print(pt.get_string(sortby=order))
-    else:
-        print(encodeutils.safe_encode(pt.get_string(sortby=order)))
+    print(pt.get_string(sortby=order))
 
 
 def print_list(objs, fields, exclude_unavailable=False, formatters=None,
@@ -158,7 +150,7 @@ def print_list(objs, fields, exclude_unavailable=False, formatters=None,
                         data = getattr(o, field_name, '')
                 if data is None:
                     data = '-'
-                if isinstance(data, six.string_types) and "\r" in data:
+                if isinstance(data, str) and "\r" in data:
                     data = data.replace("\r", " ")
                 row.append(data)
         rows.append(row)
@@ -174,7 +166,6 @@ def print_list(objs, fields, exclude_unavailable=False, formatters=None,
         for part in row:
             count = count + 1
             if isinstance(part, dict):
-                part = unicode_key_value_to_string(part)
                 row[count - 1] = part
         pt.add_row(row)
 
@@ -185,24 +176,6 @@ def print_list(objs, fields, exclude_unavailable=False, formatters=None,
     _print(pt, order_by)
 
 
-def _encode(src):
-    """remove extra 'u' in PY2."""
-    if six.PY2 and isinstance(src, six.text_type):
-        return src.encode('utf-8')
-    return src
-
-
-def unicode_key_value_to_string(src):
-    """Recursively converts dictionary keys to strings."""
-    if isinstance(src, dict):
-        return dict((_encode(k),
-                    _encode(unicode_key_value_to_string(v)))
-                    for k, v in src.items())
-    if isinstance(src, list):
-        return [unicode_key_value_to_string(l) for l in src]
-    return _encode(src)
-
-
 def build_query_param(params, sort=False):
     """parse list to url query parameters"""
 
@@ -251,10 +224,9 @@ def print_dict(d, property="Property", formatters=None):
         r = list(r)
 
         if r[0] in formatters:
-            r[1] = unicode_key_value_to_string(r[1])
             if isinstance(r[1], dict):
                 r[1] = _pretty_format_dict(r[1])
-        if isinstance(r[1], six.string_types) and "\r" in r[1]:
+        if isinstance(r[1], str) and "\r" in r[1]:
             r[1] = r[1].replace("\r", " ")
         pt.add_row(r)
     _print(pt, property)
@@ -281,9 +253,6 @@ def find_resource(manager, name_or_id, **kwargs):
         except (ValueError, exceptions.NotFound):
             pass
 
-    if sys.version_info <= (3, 0):
-        name_or_id = encodeutils.safe_decode(name_or_id)
-
     try:
         try:
             resource = getattr(manager, 'resource_class', None)
@@ -332,18 +301,17 @@ def safe_issubclass(*args):
 
 def _load_entry_point(ep_name, name=None):
     """Try to load the entry point ep_name that matches name."""
-    for ep in pkg_resources.iter_entry_points(ep_name, name=name):
-        try:
-            return ep.load()
-        except (ImportError, pkg_resources.UnknownExtra, AttributeError):
-            continue
+    mgr = stevedore.NamedExtensionManager(
+        namespace=ep_name,
+        names=[name],
+        # Ignore errors on load
+        on_load_failure_callback=lambda mgr, entry_point, error: None,
+    )
+    try:
+        return mgr[name].plugin
+    except KeyError:
+        pass
 
 
 def get_function_name(func):
-    if six.PY2:
-        if hasattr(func, "im_class"):
-            return "%s.%s" % (func.im_class, func.__name__)
-        else:
-            return "%s.%s" % (func.__module__, func.__name__)
-    else:
-        return "%s.%s" % (func.__module__, func.__qualname__)
+    return "%s.%s" % (func.__module__, func.__qualname__)
